@@ -129,6 +129,12 @@ async def websocket_handler(request):
                                 res = await handleRequest( json.loads(msg.data), False, False)
                                 copy_obj = copy.deepcopy(json.loads(res))
                                 copy_obj["result"]["timestamp"] = hex(copy_obj["result"]["timestamp"])
+                                copy_obj["result"]["k"] = hex(copy_obj["result"]["k"])
+                                copy_obj["result"]["gasLimit"] = hex(copy_obj["result"]["gasLimit"])
+                                copy_obj["result"]["gasUsed"] = hex(copy_obj["result"]["gasUsed"])
+                                copy_obj["result"]["nonce"] = hex(copy_obj["result"]["nonce"])
+                                copy_obj["result"]["epoch"] = hex(copy_obj["result"]["epoch"])
+
                                 # convert the subscription object into an appropriate response
                                 res_obj = {"jsonrpc": copy_obj["jsonrpc"] , "method":"eth_subscription", "params":{"result":copy_obj["result"], "subscription":"0x00640404976e52864c3cfd120e5cc28aac3f644748ee6e8be185fb780cdfd827"}}
                                 await ws.send_str(json.dumps(res_obj))
